@@ -1399,6 +1399,20 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_transit_money <err_msg> {e} from {AssetInfo.__tablename__}')
 
+    def get_asset_info_by_type(self, asset_type: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    AssetInfo,
+                )
+                if asset_type:
+                    query = query.filter(
+                        AssetInfo.asset_type.in_(asset_type),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_transit_money <err_msg> {e} from {AssetInfo.__tablename__}')
+
     def get_asset_details(self):
         try:
             df = self.get_asset_info()
