@@ -8,9 +8,9 @@ from sqlalchemy import func
 from ...util.singleton import Singleton
 from ..wrapper.mysql import DerivedDatabaseConnector
 from .raw import RawDataApi
+from .basic import BasicDataApi
 from ..view.derived_models import *
 
-
 class DerivedDataApi(metaclass=Singleton):
     def get_fund_indicator(self, fund_list):
         with DerivedDatabaseConnector().managed_session() as quant_session:
@@ -183,6 +183,93 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
                 return pd.DataFrame([])
 
+    def get_index_val_info(self):
+        dic = {
+            'A股指数PE估值':{
+                'index_ids':['sse50','hs300','csi500','gem_50'],
+                'val':'pe_ttm',
+            },
+            'A股指数PB估值':{
+                'index_ids':['sse50','hs300','csi500','gem_50'],
+                'val':'pb_mrq',
+            },
+            '港股指数PE估值':{
+                'index_ids':['hsi','hsi_stateown','hsi_ita','hsi_china25','hsi_mssize','hsi_shkscne','hsi_intertec'],
+                'val':'pe_ttm',
+            },
+            '港股指数PB估值':{
+                'index_ids':['hsi','hsi_stateown','hsi_ita','hsi_china25','hsi_mssize','hsi_shkscne','hsi_intertec'],
+                'val':'pb_mrq',
+            },
+            '风格指数PE估值':{
+                'index_ids':['csi300_growth','csi300_value','csi800_value','csi800_growth'],
+                'val':'pe_ttm',
+            },
+            '风格指数PB估值':{
+                'index_ids':['csi300_growth','csi300_value','csi800_value','csi800_growth'],
+                'val':'pb_mrq',
+            },
+            '行业指数PE估值':{
+                'index_ids':BasicDataApi().get_asset_info_by_type(['行业指数']).real_id.tolist(),
+                'val':'pe_ttm',
+            },
+            '行业指数PB估值':{
+                'index_ids':BasicDataApi().get_asset_info_by_type(['行业指数']).real_id.tolist(),
+                'val':'pb_mrq',
+            },
+            '主题指数PE估值':{
+                'index_ids':BasicDataApi().get_asset_info_by_type(['主题指数']).real_id.tolist(),
+                'val':'pe_ttm',
+            },
+            '主题指数PB估值':{
+                'index_ids':BasicDataApi().get_asset_info_by_type(['主题指数']).real_id.tolist(),
+                'val':'pb_mrq',
+            },
+        }
+        return dic
+
+    def get_index_val_detail(self):
+        index_group = ['A股指数','港股指数','风格指数','行业指数','主题指数']
+        index_val = ['PE','PB']
+        data = {'index_group':index_group,'index_val':index_val}
+        return data
+
+    def get_index_valuation_with_period(self, begin_date, end_date, time_para, index_group='A股指数', index_val='PE'):
+        data_type = f'{index_group}{index_val}估值'
+        inputs_dic = self.get_index_val_info()
+        index_ids = inputs_dic[data_type]['index_ids']
+        columns = [inputs_dic[data_type]['val']]
+        begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(
+                    IndexValuationLongTerm.index_id,
+                    IndexValuationLongTerm.datetime,
+                ).add_columns(*columns).filter(
+                    IndexValuationLongTerm.index_id.in_(index_ids),
+                    IndexValuationLongTerm.datetime >= begin_date,
+                    IndexValuationLongTerm.datetime <= end_date,
+                ).order_by(IndexValuationLongTerm.datetime.asc())
+                df = pd.read_sql(query.statement, query.session.bind)
+                l = df.columns.tolist()
+                value_col = [i for i in l if i not in ['datetime','index_id']][0]
+                index_info = BasicDataApi().get_index_info(index_ids)
+                desc_dic = index_info.set_index('index_id').to_dict()['desc_name']
+                df = df.pivot_table(columns='index_id',values=value_col,index='datetime')
+                df.loc['中位数',:] = df.median()
+                df.loc['最大值',:] = df.max()
+                df.loc['最小值',:] = df.min()
+                df.loc['现值',:] = df.ffill().iloc[-1]
+                df = df.rename(columns=desc_dic)
+                df = df.loc[['中位数','最大值','最小值','现值']].round(2)   
+                cols = df.columns.tolist()
+                name_dic = {i:i.replace('(申万)','') for i in cols}
+                df = df.rename(columns=name_dic).rename(columns={'HKCTMT人民币':'沪港通TMT'}) 
+                return {'data':df,'title':data_type}
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
+                return pd.DataFrame([])
+
     def get_index_valuation_develop_without_date(self, index_ids):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
