@@ -202,8 +202,8 @@ class OverseaFundNavAnalysis:
                     continue
                 fund_nav_i = self.fund_nav[[fund_id]]
                 fund_nav_adj_i = self.fund_nav_adj[[fund_id]]
-                #benchmark_id = self.fund_info.loc[fund_id].benchmark_final
-                benchmark_id = self.ASSET_BENCHMARK[self.fund_benchmark_dic[fund_id]]
+                benchmark_id = self.fund_info.loc[fund_id].benchmark_final
+                #benchmark_id = self.ASSET_BENCHMARK[self.fund_benchmark_dic[fund_id]]
                 
                 if not benchmark_id in self.index_price or benchmark_id in ['USC0TR03','G0O1','I02885JP']:
                     benchmark_id = self.DEFAULT_BENCHMARK[self.fund_info.loc[fund_id,'fund_type']]
@@ -249,7 +249,9 @@ class OverseaFundNavAnalysis:
             _df = pd.concat(res)
             _df = _df.drop(columns=['start_date']).rename(columns={'end_date':'datetime'})
             _df = _df.replace(np.Inf,np.nan).replace(-np.Inf,np.nan)
-            self._data_helper._upload_raw(_df, QSOverseaFundIndicator.__table__.name, to_truncate=True)
+            total_columns = list(QSOverseaFundIndicator.__table__.columns.keys())
+            _df = _df[_df.columns.intersection(total_columns)]
+            self._data_helper._upload_raw(_df, QSOverseaFundIndicator.__table__.name)
         except Exception as e:
             print(e)
             traceback.print_exc()
@@ -295,7 +297,7 @@ class OverseaFundNavAnalysis:
                 'total_score':int,
             }
             _df = _df.astype(type_dic)
-            self._data_helper._upload_raw(_df, QSOverseaFundRadarScore.__table__.name, to_truncate=True)
+            self._data_helper._upload_raw(_df, QSOverseaFundRadarScore.__table__.name)
         except Exception as e:
             print(e)
             traceback.print_exc()
