@@ -8,6 +8,7 @@ import traceback
 import time
 
 import pandas as pd
+import pdfplumber
 
 from ...util.mail_retriever import MailAttachmentRetriever, IMAP_SPType, UID_FILE_NAME
 from ...util.wechat_bot import WechatBot
@@ -179,6 +180,22 @@ class HedgeFundNAVReader:
         df['datetime'] = df.datetime.transform(lambda x: pd.to_datetime(str(x), infer_datetime_format=True).date())
         return df
 
+    @staticmethod
+    def _read_for_JinDeChengYiJingXin2(file_path: str) -> pd.DataFrame:
+        data = []
+        with pdfplumber.open(file_path) as pdf:
+            first_page = pdf.pages[0]
+            the_date = pd.to_datetime(re.sub('年|月|日', "-", first_page.extract_words()[5]['text'])[:-1], infer_datetime_format=True).date()
+            for one in first_page.extract_tables({'vertical_strategy': 'text'})[0][1:3]:
+                data.append(one[0].split())
+        df = pd.Series(data[1], index=data[0]).to_frame().T
+        df = df[['单位净值']]
+        df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
+        df['fund_id'] = 'SJJ077'
+        df['datetime'] = the_date
+        df['acc_unit_value'] = df['net_asset_value']
+        return df
+
     def _notify_error_event(self, err_msg: str):
         print(f'[read_navs_and_dump_to_db] {err_msg}')
         self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
@@ -204,7 +221,7 @@ class HedgeFundNAVReader:
         df_list: List[pd.DataFrame] = []
         for name, comp_date in data.items():
             uid, file_path = comp_date
-            if '.xls' not in name and '.xlsx' not in name:
+            if '.xls' not in name and '.xlsx' not in name and 'pdf' not in name:
                 self._notify_error_event(f'not a valid file, do not process it (name){name} (file_path){file_path}')
                 continue
 
@@ -240,6 +257,8 @@ class HedgeFundNAVReader:
                     df = HedgeFundNAVReader._read_for_YuanHui1(file_path)
                 elif '卓识佳鑫' in name:
                     df = HedgeFundNAVReader._read_for_ZhuoShiJiaXin(file_path)
+                elif '金锝诚意精心2号' in name:
+                    df = HedgeFundNAVReader._read_for_JinDeChengYiJingXin2(file_path)
                 else:
                     raise NotImplementedError('unknown hedge fund nav file from attachment')
             except Exception as e:
@@ -314,6 +333,7 @@ class HedgeFundNAVReader:
             print(df)
             df.update(now_df.set_index(['fund_id', 'datetime']), overwrite=False)
             df = df.reset_index()
+            df['datetime'] = df.datetime.map(lambda x: x.date())
             print(df)
             # 先删后添
             for fund_id in df.fund_id.unique():
