@@ -32,9 +32,12 @@ class SeriesStatUnit:
     annualized_vol: float               # 年化波动率
     sharpe: float                       # 夏普率
     recent_year_ret: float              # 最近自然年收益
+    recent_1w_ret: float                # 最近1周收益
     recent_1m_ret: float                # 最近1月收益
+    recent_4w_ret: float                # 最近4周收益
     recent_3m_ret: float                # 最近3月收益
     recent_6m_ret: float                # 最近6月收益
+    y_2020_ret: float                   # 2020年收益
     recent_y1_ret: float                # 近一年收益
     recent_y3_ret: float                # 近三年收益
     recent_y5_ret: float                # 近五年收益
@@ -155,7 +158,10 @@ class Calculator:
             annualized_vol=res['annual_vol'],
             sharpe=res['sharpe'],
             cumu_ret=res['cumu_ret'],
+            recent_1w_ret=res['recent_1w_ret'],
             recent_1m_ret=res['recent_1m_ret'],
+            recent_4w_ret=res['recent_4w_ret'],
+            y_2020_ret=res['y_2020_ret'],
             recent_3m_ret=res['recent_3m_ret'],
             recent_6m_ret=res['recent_6m_ret'],
             recent_y1_ret=res['recent_1y_ret'],
@@ -228,7 +234,10 @@ class Calculator:
             ir=res['info'],
             last_mv_diff=res['last_mv_diff'],
             last_increase_rate=res['last_increase_rate'],
+            recent_1w_ret=res['recent_1w_ret'],
             recent_1m_ret=res['recent_1m_ret'],
+            recent_4w_ret=res['recent_4w_ret'],
+            y_2020_ret=res['y_2020_ret'],
             recent_3m_ret=res['recent_3m_ret'],
             recent_6m_ret=res['recent_6m_ret'],
             recent_y1_ret=res['recent_1y_ret'],
@@ -264,6 +273,7 @@ class Calculator:
             sortino=res['sortino'],
             skew=res['skew'],
             kurtosis=res['kurtosis'],
+            cumu_ret=res['cumu_ret'],
         )
 
     @staticmethod
@@ -1025,6 +1035,7 @@ class Calculator:
         df = df.pct_change(1).iloc[1:].corr().round(3)
         df = df.sort_values(df.columns[0], ascending=False)
         df.index.name = 'index_id'
+        df = df[df.index.tolist()]
         return df
 
 if __name__ == "__main__":
