@@ -145,10 +145,19 @@ class CalculatorBase:
         history_ret = sr.loc[:last_date][-1] / sr[0] - 1
         days = (dates[-1] - dates[0]).days
         history_annual_ret = math.pow(history_ret + 1, CalculatorBase.TOTAL_DAYS_PER_YEAR/days) - 1
+        sr_week = CalculatorBase.data_resample_weekly_nav(sr,rule='W-FRI')
+        recent_4w_ret=sr_week[-1] / sr_week[-5] - 1
         
+        _date_20_b = datetime.date(2019,12,31)
+        _date_20_e = datetime.date(2020,12,31)
+        date_20_b = max(sr.index.min(),_date_20_b)
+        date_20_e = min(sr.index.max(),_date_20_e)
+        _sr = sr[date_20_b:date_20_e]
+        y_2020_ret = _sr[-1] / _sr[0] - 1 if not _sr.empty else None
         return {
             'recent_natural_year_ret':recent_natural_year_ret,
             'recent_1w_ret':recent_1w_ret,
+            'recent_4w_ret':recent_4w_ret,
             'recent_1m_ret':recent_1m_ret,
             'recent_3m_ret':recent_3m_ret,
             'recent_6m_ret':recent_6m_ret,
@@ -159,6 +168,7 @@ class CalculatorBase:
             'recent_5y_ret':recent_5y_ret,
             'history_ret':history_ret,
             'history_annual_ret':history_annual_ret,
+            'y_2020_ret':y_2020_ret,
         }
 
     @staticmethod
@@ -383,6 +393,8 @@ class CalculatorBase:
             recent_1y_ret = recent_ret_res['recent_1y_ret']
             recent_3y_ret = recent_ret_res['recent_3y_ret']
             recent_5y_ret = recent_ret_res['recent_5y_ret']
+            recent_4w_ret = recent_ret_res['recent_4w_ret']
+            y_2020_ret = recent_ret_res['y_2020_ret']
             worst_3m_ret = sr.pct_change(period_3m).min()
             worst_6m_ret = sr.pct_change(period_6m).min()
             last_mv_diff = sr[-1] - sr[-2]
@@ -522,6 +534,8 @@ class CalculatorBase:
                     'recent_year_ret':recent_year_ret,
                     'recent_1w_ret':recent_1w_ret,
                     'recent_1m_ret':recent_1m_ret,
+                    'recent_4w_ret':recent_4w_ret,
+                    'y_2020_ret':y_2020_ret,
                     'recent_3m_ret':recent_3m_ret,
                     'recent_6m_ret':recent_6m_ret,
                     'recent_1y_ret':recent_1y_ret,
@@ -590,6 +604,8 @@ class CalculatorBase:
                     'recent_year_ret':recent_year_ret,
                     'recent_1w_ret':recent_1w_ret,
                     'recent_1m_ret':recent_1m_ret,
+                    'recent_4w_ret':recent_4w_ret,
+                    'y_2020_ret':y_2020_ret,
                     'recent_3m_ret':recent_3m_ret,
                     'recent_6m_ret':recent_6m_ret,
                     'recent_1y_ret':recent_1y_ret,
@@ -630,6 +646,8 @@ class CalculatorBase:
                     'recent_year_ret':0,
                     'recent_1w_ret':0,
                     'recent_1m_ret':0,
+                    'recent_4w_ret':0,
+                    'y_2020_ret':0,
                     'recent_3m_ret':0,
                     'recent_6m_ret':0,
                     'recent_1y_ret':0,
