@@ -63,7 +63,7 @@ class MailAttachmentRetriever:
                                     real_name = email.header.decode_header(filename)[0][0]
                                     if isinstance(real_name, bytes):
                                         real_name = real_name.decode(email.header.decode_header(filename)[0][1])
-                                    if real_name.endswith('.xls') or real_name.endswith('xlsx'):
+                                    if real_name.endswith('.xls') or real_name.endswith('xlsx') or real_name.endswith('pdf'):
                                         # pandas可以直接读，但pd.read_excel()里传的参数可能是不一样的，所以这里还是先将内容写到文件里
                                         if real_name == '产品净值情况.xlsx':
                                             real_name = f'产品净值情况_{uid}.xlsx'
